summaryrefslogtreecommitdiffstats
path: root/commands
diff options
context:
space:
mode:
authorJan Pokorný <jpokorny@redhat.com>2015-06-09 18:07:05 +0200
committerJan Pokorný <jpokorny@redhat.com>2015-06-19 17:32:23 +0200
commit8f1acd21cdaf0a07e74cbc22bd0bbc26bc924a5d (patch)
tree5ae4d59776aa8f6067283ccb1bfbd0f4a5aa1e7d /commands
parent65471ae7f70d012b46b80acc48ed0dcefbef4fb9 (diff)
downloadclufter-8f1acd21cdaf0a07e74cbc22bd0bbc26bc924a5d.tar.gz
clufter-8f1acd21cdaf0a07e74cbc22bd0bbc26bc924a5d.tar.xz
clufter-8f1acd21cdaf0a07e74cbc22bd0bbc26bc924a5d.zip
commands/ccs2pcscmd-flatiron: add "--start-wait" switch
Also adjust the test case. Signed-off-by: Jan Pokorný <jpokorny@redhat.com>
Diffstat (limited to 'commands')
-rw-r--r--commands/ccs2pcscmd.py19
1 files changed, 11 insertions, 8 deletions
diff --git a/commands/ccs2pcscmd.py b/commands/ccs2pcscmd.py
index 436e6d7..5330d2b 100644
--- a/commands/ccs2pcscmd.py
+++ b/commands/ccs2pcscmd.py
@@ -29,18 +29,20 @@ def ccs2pcscmd_flatiron(cmd_ctxt,
tmp_cib="tmp-cib.xml", # ~ filters.cib2pcscmd.TMP_CIB
dry_run=False,
enable=False,
+ start_wait=90,
_common=XMLFilter.command_common):
"""(CMAN,rgmanager) cluster cfg. -> equivalent in pcs commands
Options:
input input (CMAN,rgmanager) cluster config. file
output pcs commands to reinstate the cluster per the inputs
force may the force be with emitted pcs commands
noauth skip authentication step (OK if already set up)
silent do not track the progress along the steps execution (echoes)
tmp_cib file to accumulate the changes (empty ~ direct push)
dry_run omit intrusive commands (TMP_CIB reset if empty)
enable enable cluster infrastructure services (autostart on reboot)
"""
if dry_run and not tmp_cib:
@@ -51,6 +53,7 @@ def ccs2pcscmd_flatiron(cmd_ctxt,
cmd_ctxt['pcscmd_tmpcib'] = tmp_cib
cmd_ctxt['pcscmd_dryrun'] = dry_run
cmd_ctxt['pcscmd_enable'] = enable
+ cmd_ctxt['pcscmd_start_wait'] = start_wait
file_proto = protocols.plugins['file'].ensure_proto
return (
file_proto(input),
@@ -29,18 +29,20 @@ def ccs2pcscmd_flatiron(cmd_ctxt,
"""(CMAN,rgmanager) cluster cfg. -> equivalent in pcs commands
Options:
- input input (CMAN,rgmanager) cluster config. file
- output pcs commands to reinstate the cluster per the inputs
- force may the force be with emitted pcs commands
- noauth skip authentication step (OK if already set up)
- silent do not track the progress along the steps execution (echoes)
- tmp_cib file to accumulate the changes (empty ~ direct push)
- dry_run omit intrusive commands (TMP_CIB reset if empty)
- enable enable cluster infrastructure services (autostart on reboot)
+ input input (CMAN,rgmanager) cluster config. file
+ output pcs commands to reinstate the cluster per the inputs
+ force may the force be with emitted pcs commands
+ noauth skip authentication step (OK if already set up)
+ silent do not track the progress along the steps execution (echoes)
+ tmp_cib file to accumulate the changes (empty ~ direct push)
+ dry_run omit intrusive commands (TMP_CIB reset if empty)
+ enable enable cluster infrastructure services (autostart on reboot)
+ start_wait fixed seconds to give cluster to come up initially
"""
if dry_run and not tmp_cib: